@@ -1,6 +1,6 @@
 /*global Sentry:true*/
 
-(function(app, Backbone, jQuery, _){
+(function(window, app, Backbone, jQuery, _){
     "use strict";
 
     var $ = jQuery;
@@ -106,7 +106,9 @@
             }, this));
 
             $('#chart').height('50px');
-            app.charts.render('#chart');
+            app.charts.render('#chart', {
+                placement: 'left'
+            });
         },
 
         updateStreamOptions: function(){
@@ -141,10 +143,106 @@
         initialize: function(data){
             BasePage.prototype.initialize.call(this, data);
 
+            this.group_list = new app.GroupListView({
+                className: 'group-list',
+                id: 'event_list',
+                members: [data.group],
+                model: app.Group
+            });
+
             $('#chart').height('200px');
             Sentry.charts.render('#chart');
-        }
 
+            $('#public-status .action').click(function(){
+                var $this = $(this);
+                $.ajax({
+                    url: $this.attr('data-api-url'),
+                    type: 'post',
+                    dataType: 'json',
+                    success: function(groups){
+                        var group = groups[0];
+                        var selector = (group.is_public ? 'true' : 'false');
+                        var nselector = (group.is_public ? 'false' : 'true');
+                        $('#public-status span[data-public="' + selector + '"]').show();
+                        $('#public-status span[data-public="' + nselector + '"]').hide();
+                    },
+                    error: function(){
+                        window.alert('There was an error changing the public status');
+                    }
+                });
+            });
+
+            var $event_nav = $('#event_nav');
+            if ($event_nav) {
+                var $window = $(window);
+                var $nav_links = $event_nav.find('a[href*=#]');
+                var $nav_targets = [];
+                var scroll_offset = $event_nav.offset().top;
+                var event_nav_height;
+                var last_target;
+
+                $nav_links.click(function(e){
+                    var $el = $(this);
+                    var target = $(this.hash);
+
+                    $el.parent().addClass('active').siblings().removeClass('active');
+
+                    $('html,body').animate({
+                        scrollTop: $(target).position().top + event_nav_height + 20
+                    }, 'fast');
+
+                    e.preventDefault();
+                }).each(function(){
+                    if (this.hash.length > 1 && $(this.hash).length) {
+                        $nav_targets.push(this.hash);
+                    }
+                });
+
+                $window.resize(function(){
+                    event_nav_height = $event_nav.find('.nav').outerHeight();
+                    $event_nav.height(event_nav_height + 'px');
+                }).resize();
+
+                $window.scroll(function(){
+                    // Change fixed nav if needed
+                    if ($window.scrollTop() > scroll_offset) {
+                        if (!$event_nav.hasClass('fixed')) {
+                            $event_nav.addClass('fixed');
+                        }
+                    } else if ($event_nav.hasClass('fixed')) {
+                        $event_nav.removeClass('fixed');
+                    }
+
+                    if ($nav_targets.length) {
+                        // Get container scroll position
+                        var from_top = $window.scrollTop() + event_nav_height + 20;
+                       
+                        // Get id of current scroll item
+                        var cur = $.map($nav_targets, function(hash){
+                            if ($(hash).offset().top < from_top) {
+                                return hash;
+                            }
+                        });
+
+                        // Get the id of the current element
+                        var target = cur ? cur[cur.length - 1] : null;
+
+                        if (!target) {
+                            target = $nav_targets[0];
+                        }
+
+                        if (last_target !== target) {
+                           last_target = target;
+
+                           // Set/remove active class
+                           $nav_links
+                             .parent().removeClass("active")
+                             .end().filter("[href=" + target + "]").parent().addClass("active");
+                        }  
+                    }
+                }).scroll();
+            }
+        }
     });
 
     app.NewProjectPage = BasePage.extend({
@@ -246,4 +344,4 @@
     Backbone.sync = function(method, model, success, error){
         success();
     };
-}(app, Backbone, jQuery, _));
\ No newline at end of file
+}(window, app, Backbone, jQuery, _));
\ No newline at end of file
