@@ -20,18 +20,22 @@ STATIC_PATH_CACHE = {}
 
 
 @login_required
-def dashboard(request):
+def dashboard(request, template='dashboard.html'):
     project_list = get_project_list(request.user, key='slug')
     has_projects = len(project_list) > 1 or (len(project_list) == 1 and project_list.values()[0].pk != settings.PROJECT)
 
     if not has_projects:
         if not request.user.is_authenticated():
-            request.session['_next'] = request.build_absolute_uri()
+            request.session['_next'] = request.get_full_path()
             return HttpResponseRedirect(get_login_url())
         elif can_create_projects(request.user):
             return HttpResponseRedirect(reverse('sentry-new-project'))
 
-    return render_to_response('sentry/dashboard.html', {}, request)
+    return render_to_response('sentry/%s' % template, {}, request)
+
+
+def wall_display(request):
+    return dashboard(request, 'wall.html')
 
 
 def static_media(request, module, path, root=None):
@@ -49,7 +53,9 @@ def static_media(request, module, path, root=None):
     if root:
         document_root = root
     elif module == 'sentry':
-        document_root = os.path.join(settings.MODULE_ROOT, 'static', 'sentry')
+        document_root = os.path.join(settings.MODULE_ROOT, 'static', module)
+    elif module == dj_settings.COMPRESS_OUTPUT_DIR:
+        document_root = os.path.join(dj_settings.STATIC_ROOT, module)
     elif module not in dj_settings.INSTALLED_APPS:
         raise Http404('Invalid module provided.')
     else:
